#ifndef UT_THEME_PROXY_TEST_H
#define UT_THEME_PROXY_TEST_H

#include "gtest/gtest.h"
#include <QTest>


class ut_theme_proxy_test : public testing::Test
{
public:
    ut_theme_proxy_test();
};

#endif // UT_THEME_PROXY_TEST_H
